﻿using System.Windows;
using System.Windows.Controls;
using System.Windows.Controls.DataVisualization.Charting;
using System.Windows.Media;
using System.Windows.Printing;

namespace ChartPrinting
{
    public partial class MainPage : UserControl
    {
        public MainPage()
        {
            InitializeComponent();
        }

        private void Button_Click(object sender, RoutedEventArgs e)
        {
            // Create customized content for printing
            var chart = new Chart { Title = "My Printed Chart" };
            var series = new LineSeries
            {
                ItemsSource = (PointCollection)Resources["Items"],
                DependentValuePath = "Y",
                IndependentValuePath = "X",
            };
            chart.Series.Add(series);
            var content = new Border
            {
                BorderBrush = new SolidColorBrush(Colors.Magenta),
                BorderThickness = new Thickness(10),
                Child = chart,
            };

            // Create container for putting content in the visual tree invisibly
            var visualTreeContainer = new Grid
            {
                Width = 1000,
                Height = 1000,
                Opacity = 0,
            };

            // Put content in the visual tree to initialize
            visualTreeContainer.Children.Add(content);
            LayoutRoot.Children.Add(visualTreeContainer);

            // Prepare to print
            var printDocument = new PrintDocument();
            printDocument.PrintPage += delegate(object obj, PrintPageEventArgs args)
            {
                // Unparent the content for adding to PageVisual
                visualTreeContainer.Children.Remove(content);
                args.PageVisual = content;
            };

            // Print the content
            printDocument.Print();

            // Remove container from the visual tree
            LayoutRoot.Children.Remove(visualTreeContainer);
        }
    }
}
